@@ -25,7 +25,7 @@ class SubDemo(Module):
     return ["".join(random.choices(CHAR_LIST, k=int(1 + random.random() * 10))) for d in range(size)]
 
   @Module.laboro_method
-  def get_random_list(self, size):
+  def get_random_list(self, size=5):
     """Generate a list of the specified size.
 
     Arguments:
